@@ -61,11 +61,18 @@ GType champlain_base_marker_get_type (void);
 ClutterActor *champlain_base_marker_new (void);
 
 void champlain_base_marker_set_position (ChamplainBaseMarker *marker,
-    gdouble longitude, gdouble latitude);
+    gdouble latitude, gdouble longitude);
 void champlain_base_marker_set_highlighted (ChamplainBaseMarker *marker,
     gboolean value);
 gboolean champlain_base_marker_get_highlighted (ChamplainBaseMarker *marker);
 
+void champlain_base_marker_animate_in (ChamplainBaseMarker *marker);
+void champlain_base_marker_animate_in_with_delay (ChamplainBaseMarker *marker,
+    guint delay);
+void champlain_base_marker_animate_out (ChamplainBaseMarker *marker);
+void champlain_base_marker_animate_out_with_delay (ChamplainBaseMarker *marker,
+    guint delay);
+
 G_END_DECLS
 
 #endif
