@@ -1,5 +1,5 @@
 
-/* Generated data (by glib-mkenums) */
+
 
 #ifndef __CHAMPLAIN_ENUM_TYPES_H__
 #define __CHAMPLAIN_ENUM_TYPES_H__ 1
@@ -11,6 +11,8 @@ G_BEGIN_DECLS
 #include <champlain/champlain-defines.h>
 #define CHAMPLAIN_TYPE_STATE champlain_state_get_type()
 GType champlain_state_get_type (void);
+#define CHAMPLAIN_TYPE_UNIT champlain_unit_get_type()
+GType champlain_unit_get_type (void);
 #include <champlain/champlain-view.h>
 #define CHAMPLAIN_TYPE_SCROLL_MODE champlain_scroll_mode_get_type()
 GType champlain_scroll_mode_get_type (void);
@@ -24,5 +26,5 @@ G_END_DECLS
 
 #endif /* __CHAMPLAIN_ENUM_TYPES_H__ */
 
-/* Generated data ends here */
+
 
